
---
title: teedoc
keywords: teedoc, markdown, jupyter notebook, html, 文档生成, 替代gitbook, 网站生成, 静态网站, 文档网站生成, 多文档, 静态博客
desc: teedoc， 将 markdown 或者 jupyter notbook 转换成 html 静态网页， 用于个人或企业建站，建博客，建资料库，wiki等
---




<div id="home_page">
    <div>
        <h1><span>teedoc</span></h1>
        <h3>简而全的网站/文档/博客生成器</h3>
    </div>
    <div id="big_btn_wrapper">
        <div class="big_btn">
            <a href="/get_started/zh/">开始使用</a>
        </div>
    </div>

</div>

